Développement
=============

Pour développer dans ce projet, il vous faut s'assurer que toutes
les dépendances sont installées, voir la section :ref:`install`.
Ensuite, clôner le projet:

.. code-block:: console

   git clone git@vcs.optelgroup.com:btech/bi/data-refinery/datalake.git

Pour terminer, assurer vous que vous pouvez construire la documentation
et passer les tests:

.. code-block:: console

   python setup.py docs
   pytest

Si tout se passe bien, vous êtes en mesure de développer.

.. todolist::
